@@ -16,10 +16,12 @@ from . import headers
 
 logger = get_logger(__name__)
 _initialized = False
+_consumers_enabled = True
 
 
-def __init__():
+def __init__(enable_consumers: bool = True):
     global _initialized
+    global _consumers_enabled
 
     if _initialized:
         return
@@ -38,10 +40,13 @@ def __init__():
         initialization_connection.close()
 
     routing.__init__()
-    consumer.__init__(connection_factory)
+    if enable_consumers:
+        consumer.__init__(connection_factory)
+
     publisher.__init__(connection_factory)
 
     _initialized = True
+    _consumers_enabled = True
 
 
 def _declare_dead_letter_exchange(connection: ReconnectingAMQPConnection):
@@ -65,6 +70,8 @@ def _declare_waiting_transcription_result_exchange(connection: ReconnectingAMQPC
 
 
 def push(message, ttl_millis: Optional[int] = None, headers: Dict[str, str] = None):
+    assert _initialized, 'Module not initialized, call __init__()'
+
     from .publisher import publisher
 
     publisher.push(message, ttl_millis=ttl_millis, headers=headers)
@@ -72,6 +79,8 @@ def push(message, ttl_millis: Optional[int] = None, headers: Dict[str, str] = No
 
 def push_to_routes(message, routes: List[Route], ttl_millis: Optional[int] = None,
                    headers: Dict[str, str] = None):
+    assert _initialized, 'Module not initialized, call __init__()'
+
     from .publisher import publisher
 
     publisher.push_to_routes(message, routes=routes, ttl_millis=ttl_millis, headers=headers)
@@ -93,6 +102,9 @@ def consume(queue: Queue, dtype: Optional[Type] = None, exchange: Exchange = DEF
     :return: decorator
     """
     def decorator(func):
+        assert _initialized, 'Module not initialized, call __init__()'
+        assert _consumers_enabled, 'Consumers not enabled'
+
         from .consumer import consumer_manager
 
         queue_consumer = Consumer(queue=queue, exchange=exchange, dtype=dtype, callback=func, auto_ack=auto_ack)
