@@ -329,7 +329,7 @@ class ConsumerManager(MessageListener):
                         ack_message = False
 
         if not delivered:
-            raise NoConsumerException()
+            raise NoConsumerException(message_type=type(payload))
 
         return ack_message
 
